package com.gainscha.bt_sample_code;

import androidx.appcompat.app.AppCompatActivity;

import android.content.res.AssetManager;
import android.os.Build;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;


import com.gainscha.gtspl_sdk.GTSPLActivity;

import java.io.BufferedInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {

    Button mConnectBT, mDisconnectBT, mPrinterSetup, mPrintBarcode, mPrintFontCN,mPrintFontTW, mPrintBmp, mGetStatus,mGetSDKVersion;
    EditText mMacAddress, mPrinterStatusTxt,mSDKVersionTxt;
    GTSPLActivity mGtsplCmdTest = new GTSPLActivity();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        mConnectBT = findViewById(R.id.connect);
        mDisconnectBT = findViewById(R.id.disconnect);
        mPrinterSetup = findViewById(R.id.setup);
        mPrintBarcode = findViewById(R.id.print_barcode);
        mPrintFontCN = findViewById(R.id.print_font_cn);
        mPrintFontTW= findViewById(R.id.print_font_tw);
        mPrintBmp = findViewById(R.id.print_bmp);
        mGetStatus = findViewById(R.id.get_printer_status);
        mGetSDKVersion=findViewById(R.id.get_sdk_version);

        mConnectBT.setOnClickListener(this);
        mDisconnectBT.setOnClickListener(this);
        mPrinterSetup.setOnClickListener(this);
        mPrintBarcode.setOnClickListener(this);
        mPrintFontCN.setOnClickListener(this);
        mPrintFontTW.setOnClickListener(this);
        mPrintBmp.setOnClickListener(this);
        mGetStatus.setOnClickListener(this);
        mGetSDKVersion.setOnClickListener(this);


        mMacAddress = findViewById(R.id.macaddress);
        mPrinterStatusTxt = findViewById(R.id.printer_status_txt);
        mSDKVersionTxt=findViewById(R.id.sdk_version_txt);

        //set to print mode
        //mGtsplCmdTest.GTSPL_setCmdSendMode("P");

        //save CIRCLE.BMP to loacal file
        getAssetsFile();
    }

    @Override
    public void onClick(View view) {
        switch (view.getId()) {
            case R.id.connect:
                if (mMacAddress.getText().toString().isEmpty()) {
                    Toast.makeText(this, "The macaddress column is empty", Toast.LENGTH_SHORT).show();
                } else {
                    boolean isConnect = mGtsplCmdTest.GTSPL_openPort(mMacAddress.getText().toString().trim().toUpperCase()); // 要大寫
                    if (isConnect) {
                        Toast.makeText(this, "Connect to BT succesfully.", Toast.LENGTH_SHORT).show();
                    } else {
                        Toast.makeText(this, "Fail to connect to BT.", Toast.LENGTH_SHORT).show();
                    }
                }

                break;
            case R.id.disconnect:
                boolean isDisconnect = mGtsplCmdTest.GTSPL_closePort();
                if (isDisconnect) {
                    Toast.makeText(this, "Disconnect succesfully.", Toast.LENGTH_SHORT).show();
                } else {
                    Toast.makeText(this, "Fail to disconnect.", Toast.LENGTH_SHORT).show();
                }
                break;
            case R.id.setup:
                mGtsplCmdTest.GTSPL_setup(62, 45, 2, 6, 0, 3, 0, this);
                mGtsplCmdTest.GTSPL_sendCommand(this, "DIRECTION 1\n\n");
                Toast.makeText(this, "Setting Complete!", Toast.LENGTH_SHORT).show();
                break;
            case R.id.print_barcode:
                mGtsplCmdTest.GTSPL_clearBuffer(this);
                mGtsplCmdTest.GTSPL_barcode(30, 30, "128", 100, 1, 0, 2, 2, "barcode1234567", this);
                mGtsplCmdTest.GTSPL_printLabel(1, 1, this);
                break;
            case R.id.print_font_cn:
                //String cnTest="漆毞譙棚啞譙棚1\uF6CF蘇\uF819";
                String cnTest="默认简体中文测试：海天米醋白米醋1瓶450ml";
                mGtsplCmdTest.GTSPL_clearBuffer(this);
                mGtsplCmdTest.GTSPL_printerFont(100, 10, "TSS24.BF2", 0, 1, 1, cnTest, this);
                mGtsplCmdTest.GTSPL_printLabel(1, 1, this);
                break;
            case R.id.print_font_tw:
                String twTest="默認繁體中文測試：海天米醋白米醋1瓶450ml";
                mGtsplCmdTest.GTSPL_clearBuffer(this);
                mGtsplCmdTest.GTSPL_printerFont(100, 10, "TST24.BF2", 0, 1, 1, twTest, this);
                mGtsplCmdTest.GTSPL_printLabel(1, 1, this);
                break;
            case R.id.print_bmp:
                mGtsplCmdTest.GTSPL_clearBuffer(this);
                mGtsplCmdTest.GTSPL_downloadBMP("CIRCLE.BMP", this);
                mGtsplCmdTest.GTSPL_sendCommand(this, "PUTBMP 150,30,\"CIRCLE.BMP\"\r\n");
                mGtsplCmdTest.GTSPL_printLabel(1, 1, this);
                break;
            case R.id.get_printer_status:
                String status = mGtsplCmdTest.GTSPL_printersStatus(1000);
                setPrinterStatusToUI(status);
                break;
            case R.id.get_sdk_version:
                String version=mGtsplCmdTest.GTSPL_getSDKVersion(0,this);
                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                    mSDKVersionTxt.setTextColor(getResources().getColor(R.color.colorAccent, null));
                }
                mSDKVersionTxt.setText("SDK Version:"+version);
                break;
        }
    }

    //將assets中檔案存入手機
    private void getAssetsFile() {
        AssetManager assetManager = getAssets();
        InputStream inputStream;
        BufferedInputStream bis;
        ByteArrayOutputStream bos = null;
        try {
            inputStream = assetManager.open("CIRCLE.BMP");
            int dataLength = inputStream.available();
            bis = new BufferedInputStream(inputStream);
            byte[] buffer = new byte[dataLength];
            int len = 0;
            bos = new ByteArrayOutputStream();
            while ((len = bis.read(buffer)) != -1) {
                bos.write(buffer, 0, len);
            }


            File dir = new File(String.valueOf(getExternalFilesDir("")));
            String pathName = dir.getAbsolutePath() + "/" + "CIRCLE" + ".BMP";
            File file = new File(pathName);
            if (!file.exists()) {
                FileOutputStream output = new FileOutputStream(file);
                output.write(bos.toByteArray());
                output.close();
            }
            bis.close();
            bos.close();
            inputStream.close();

        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    //印表機狀態
    private void setPrinterStatusToUI(String status) {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            mPrinterStatusTxt.setTextColor(getResources().getColor(R.color.colorAccent, null));
        }
        switch (status) {
            case "00":
                mPrinterStatusTxt.setText("Printer Status : Normal");
                break;
            case "01":
                mPrinterStatusTxt.setText("Printer Status : Head opened");
                break;
            case "02":
                mPrinterStatusTxt.setText("Printer Status : Paper Jam");
                break;
            case "03":
                mPrinterStatusTxt.setText("Printer Status : Paper Jam and head opened");
                break;
            case "04":
                mPrinterStatusTxt.setText("Printer Status : Out of paper");
                break;
            case "05":
                mPrinterStatusTxt.setText("Printer Status : Out of paper and head opened");
                break;
            case "08":
                mPrinterStatusTxt.setText("Printer Status : Out of ribbon");
                break;
            case "09":
                mPrinterStatusTxt.setText("Printer Status : Out of ribbon and head opened");
                break;
            case "0A":
                mPrinterStatusTxt.setText("Printer Status : Out of ribbon and paper jam");
                break;
            case "0B":
                mPrinterStatusTxt.setText("Printer Status : Out of ribbon, paper jam and head opened");
                break;
            case "0C":
                mPrinterStatusTxt.setText("Printer Status : Out of ribbon and out of paper");
                break;
            case "0D":
                mPrinterStatusTxt.setText("Printer Status : Out of ribbon, out of paper and head opened");
                break;
            case "10":
                mPrinterStatusTxt.setText("Printer Status : Pause");
                break;
            case "20":
                mPrinterStatusTxt.setText("Printer Status : Printing");
                break;
            case "80":
                mPrinterStatusTxt.setText("Printer Status : Other error");
                break;
        }


    }


}
