package com.gainscha.usb_sample_code;

import androidx.appcompat.app.AppCompatActivity;

import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.res.AssetManager;
import android.hardware.usb.UsbDevice;
import android.hardware.usb.UsbManager;
import android.os.Build;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.EditText;
import android.widget.Toast;

import com.gainscha.gtspl_sdk.GTSPLUsbActivity;

import java.io.BufferedInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Iterator;

public class MainActivity extends AppCompatActivity {

    GTSPLUsbActivity mUSB = new GTSPLUsbActivity();
    EditText mDeviceName, mProductName, mSDKVersion, mPrinterStatus;
    private static final String ACTION_USB_PERMISSION = "com.android.example.USB_PERMISSION";
    private static UsbManager mUsbManager;
    private static PendingIntent mPermissionIntent;
    private static boolean hasPermissionToCommunicate = false;
    private static UsbDevice mDevice;


    private final BroadcastReceiver mUsbReceiver = new BroadcastReceiver() {
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            if (ACTION_USB_PERMISSION.equals(action)) {
                synchronized (this) {
                    UsbDevice device = intent.getParcelableExtra(UsbManager.EXTRA_DEVICE);
                    if (intent.getBooleanExtra(UsbManager.EXTRA_PERMISSION_GRANTED, false)) {
                        if (device != null) {
                            hasPermissionToCommunicate = true;
                        }
                    }
                }
            }
        }
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        mDeviceName = findViewById(R.id.deviceName);
        mProductName = findViewById(R.id.productName);
        mSDKVersion = findViewById(R.id.sdk_version_txt);
        mPrinterStatus = findViewById(R.id.printer_status_txt);

        getUSBDevice();
        getAssetsFile();
    }

    //usb 裝置搜尋
    public void getUSBDevice() {
        mUsbManager = (UsbManager) getSystemService(Context.USB_SERVICE);
        mPermissionIntent = PendingIntent.getBroadcast(this, 0, new Intent(ACTION_USB_PERMISSION), 0);
        IntentFilter filter = new IntentFilter(ACTION_USB_PERMISSION);
        registerReceiver(mUsbReceiver, filter);

        HashMap<String, UsbDevice> deviceList = mUsbManager.getDeviceList();
        Log.d("Detect ", deviceList.size() + " USB device(s) found");
        if (deviceList.size() > 0) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                mDeviceName.setTextColor(getResources().getColor(R.color.colorAccent, null));
                mProductName.setTextColor(getResources().getColor(R.color.colorAccent, null));
            }
            Iterator<UsbDevice> deviceIterator = deviceList.values().iterator();
            while (deviceIterator.hasNext()) {
                mDevice = deviceIterator.next();
                if (mDevice.getVendorId() == 1137 || mDevice.getVendorId() ==4611) {
                    mDeviceName.setText(mDevice.getDeviceName());
                    mProductName.setText(mDevice.getProductName());
                    break;
                } else {

                    mDeviceName.setText("No device found!");
                    mProductName.setText("");
                    break;
                }
            }
            try {
                mPermissionIntent = PendingIntent.getBroadcast(MainActivity.this, 0, new Intent(ACTION_USB_PERMISSION), PendingIntent.FLAG_ONE_SHOT);
                mUsbManager.requestPermission(mDevice, mPermissionIntent);
            } catch (Exception e) {
                Toast.makeText(this, "Device disconnected!", Toast.LENGTH_SHORT).show();
            }

        } else {

            mDeviceName.setText("No device found!");
            mProductName.setText("");
        }

    }

    //search usb device again
    public void refresh_btn_click(View view) {
        getUSBDevice();
    }

    //open port
    public void connect_btn_click(View view) {
        boolean isConnect = mUSB.GTSPL_openPort(mUsbManager, mDevice);
        if (isConnect) {
            Toast.makeText(this, "Connect to USB succesfully.", Toast.LENGTH_SHORT).show();
        } else {
            Toast.makeText(this, "Fail to connect to USB.", Toast.LENGTH_SHORT).show();
        }
    }

    //close port
    public void disconnect_btn_click(View view) {
        boolean isDisconnect = mUSB.GTSPL_closePort();
        if (isDisconnect) {
            Toast.makeText(this, "Disconnect succesfully.", Toast.LENGTH_SHORT).show();
        } else {
            Toast.makeText(this, "Fail to disconnect.", Toast.LENGTH_SHORT).show();
        }
    }

    //set printer
    public void setup_btn_click(View view) {
        mUSB.GTSPL_setup(104, 76, 2, 3, 0, 3, 0, this);
        mUSB.GTSPL_sendCommand(this, "DIRECTION 1\r\n");
        Toast.makeText(this, "Setting Complete!", Toast.LENGTH_SHORT).show();
    }

    //print barcode
    public void print_barcode_btn_click(View view) {
        mUSB.GTSPL_clearBuffer(this);
        mUSB.GTSPL_barcode(30, 30, "128", 100, 1, 0, 2, 2, "barcode9463521", this);
        mUSB.GTSPL_printLabel(1, 1, this);
    }

    //print simplified chinese font
    public void print_cn_font_btn_click(View view) {
        String cnTest="默认简体中文测试：海天米醋白米醋1瓶450ml";
        mUSB.GTSPL_clearBuffer(this);
       mUSB.GTSPL_printerFont(100, 50, "TSS24.BF2", 0, 1, 1, cnTest, this);
        mUSB.GTSPL_printLabel(1, 1, this);
    }

    //print traditional chinese font
    public void print_tw_font_btn_click(View view) {
        String twTest="默認繁體中文測試：海天米醋白米醋1瓶450ml";
        mUSB.GTSPL_clearBuffer(this);
        mUSB.GTSPL_printerFont(100, 50, "TST24.BF2", 0, 1, 1, twTest, this);
        mUSB.GTSPL_printLabel(1, 1, this);

    }

    //print bmp
    public void print_bmp_btn_click(View view) {
        mUSB.GTSPL_clearBuffer(this);
        mUSB.GTSPL_downloadBMP("LOGO.BMP", this);
        mUSB.GTSPL_sendCommand(this, "PUTBMP 100,80,\"LOGO.BMP\"\r\n");
        mUSB.GTSPL_printLabel(1, 1, this);
    }


    //get printer status
    public void get_status_btn_click(View view) {
        String status = mUSB.GTSPL_printersStatus(1000);
        setPrinterStatusToUI(status);
    }

    //get sdk version
    public void get_version_btn_click(View view) {
        String version = mUSB.GTSPL_getSDKVersion(0, this);
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            mSDKVersion.setTextColor(getResources().getColor(R.color.colorAccent, null));
        }
        mSDKVersion.setText("SDK Version:" + version);
    }

    //將assets中檔案存入手機
    private void getAssetsFile() {
        AssetManager assetManager = getAssets();
        InputStream inputStream;
        BufferedInputStream bis;
        ByteArrayOutputStream bos = null;
        try {
            inputStream = assetManager.open("LOGO.BMP");
            int dataLength = inputStream.available();
            bis = new BufferedInputStream(inputStream);
            byte[] buffer = new byte[dataLength];
            int len = 0;
            bos = new ByteArrayOutputStream();
            while ((len = bis.read(buffer)) != -1) {
                bos.write(buffer, 0, len);
            }


            File dir = new File(String.valueOf(getExternalFilesDir("")));
            String pathName = dir.getAbsolutePath() + "/" + "LOGO" + ".BMP";
            File file = new File(pathName);
            if (!file.exists()) {
                FileOutputStream output = new FileOutputStream(file);
                output.write(bos.toByteArray());
                output.close();
            }
            bis.close();
            bos.close();
            inputStream.close();

        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    //印表機狀態
    private void setPrinterStatusToUI(String status) {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            mPrinterStatus.setTextColor(getResources().getColor(R.color.colorAccent, null));
        }
        switch (status) {
            case "00":
                mPrinterStatus.setText("Printer Status : Normal");
                break;
            case "01":
                mPrinterStatus.setText("Printer Status : Head opened");
                break;
            case "02":
                mPrinterStatus.setText("Printer Status : Paper Jam");
                break;
            case "03":
                mPrinterStatus.setText("Printer Status : Paper Jam and head opened");
                break;
            case "04":
                mPrinterStatus.setText("Printer Status : Out of paper");
                break;
            case "05":
                mPrinterStatus.setText("Printer Status : Out of paper and head opened");
                break;
            case "08":
                mPrinterStatus.setText("Printer Status : Out of ribbon");
                break;
            case "09":
                mPrinterStatus.setText("Printer Status : Out of ribbon and head opened");
                break;
            case "0A":
                mPrinterStatus.setText("Printer Status : Out of ribbon and paper jam");
                break;
            case "0B":
                mPrinterStatus.setText("Printer Status : Out of ribbon, paper jam and head opened");
                break;
            case "0C":
                mPrinterStatus.setText("Printer Status : Out of ribbon and out of paper");
                break;
            case "0D":
                mPrinterStatus.setText("Printer Status : Out of ribbon, out of paper and head opened");
                break;
            case "10":
                mPrinterStatus.setText("Printer Status : Pause");
                break;
            case "20":
                mPrinterStatus.setText("Printer Status : Printing");
                break;
            case "80":
                mPrinterStatus.setText("Printer Status : Other error");
                break;
            default:
                mPrinterStatus.setText("Printer Status : no status");
                break;
        }


    }

}